/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_yo extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "Greenwich Mean Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Apia = new String[] {
               "Apia Standard Time",
               "",
               "Apia Daylight Time",
               "",
               "Apia Time",
               "",
            };
        final String[] Cook = new String[] {
               "Cook Islands Standard Time",
               "",
               "Cook Islands Half Summer Time",
               "",
               "Cook Islands Time",
               "",
            };
        final String[] Cuba = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 K\u00fab\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd K\u00fab\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 K\u00fab\u00e0",
               "",
            };
        final String[] Fiji = new String[] {
               "Fiji Standard Time",
               "",
               "Fiji Summer Time",
               "",
               "Fiji Time",
               "",
            };
        final String[] Gulf = new String[] {
               "Gulf Standard Time [translation hint: translate as just \"Gulf Time\"]",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "Hovd Standard Time",
               "",
               "Hovd Summer Time",
               "",
               "Hovd Time",
               "",
            };
        final String[] Iran = new String[] {
               "Iran Standard Time",
               "",
               "Iran Daylight Time",
               "",
               "Iran Time",
               "",
            };
        final String[] Niue = new String[] {
               "Niue Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "Omsk Standard Time",
               "",
               "Omsk Summer Time",
               "",
               "Omsk Time",
               "",
            };
        final String[] Peru = new String[] {
               "Peru Standard Time",
               "",
               "Peru Summer Time",
               "",
               "Peru Time",
               "",
            };
        final String[] Truk = new String[] {
               "Chuuk Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "Wake Island Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "Chile Standard Time",
               "",
               "Chile Summer Time",
               "",
               "Chile Time",
               "",
            };
        final String[] China = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccf\u1eb9nuk\u00f2s\u00ed \u1e62\u00e1\u00edn\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd \u1e62\u00e1\u00edn\u00e0",
               "",
               "\u00c0k\u00f3k\u00f2 \u1e62\u00e1\u00edn\u00e0",
               "",
            };
        final String[] Cocos = new String[] {
               "Cocos Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "Davis Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "India Standard Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Japan = new String[] {
               "Japan Standard Time",
               "",
               "Japan Daylight Time",
               "",
               "Japan Time",
               "",
            };
        final String[] Korea = new String[] {
               "Korean Standard Time",
               "",
               "Korean Daylight Time",
               "",
               "Korean Time",
               "",
            };
        final String[] Nauru = new String[] {
               "Nauru Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "Nepal Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "Palau Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "Samoa Standard Time",
               "",
               "Samoa Daylight Time",
               "",
               "Samoa Time",
               "",
            };
        final String[] Syowa = new String[] {
               "Syowa Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "Tonga Standard Time",
               "",
               "Tonga Summer Time",
               "",
               "Tonga Time",
               "",
            };
        final String[] Alaska = new String[] {
               "Alaska Standard Time",
               "",
               "Alaska Daylight Time",
               "",
               "Alaska Time",
               "",
            };
        final String[] Amazon = new String[] {
               "Amazon Standard Time",
               "",
               "Amazon Summer Time",
               "",
               "Amazon Time",
               "",
            };
        final String[] Azores = new String[] {
               "Azores Standard Time",
               "",
               "Azores Summer Time",
               "",
               "Azores Time",
               "",
            };
        final String[] Bhutan = new String[] {
               "Bhutan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "Brunei Darussalam Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "Aago \u00e0s\u00eck\u00f2 Easter Island",
               "",
               "Aago Soma Easter Island",
               "",
               "Aago Ajnde Ib\u00f9gb\u00e9 Omi",
               "",
            };
        final String[] Guyana = new String[] {
               "Guyana Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Israel = new String[] {
               "Israel Standard Time",
               "",
               "Israel Daylight Time",
               "",
               "Israel Time",
               "",
            };
        final String[] Kosrae = new String[] {
               "Kosrae Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "Mawson Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "Moscow Standard Time",
               "",
               "Moscow Summer Time",
               "",
               "Moscow Time",
               "",
            };
        final String[] Ponape = new String[] {
               "Ponape Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tahiti = new String[] {
               "Tahiti Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "Taipei Standard Time",
               "",
               "Taipei Daylight Time",
               "",
               "Taipei Time",
               "",
            };
        final String[] Tuvalu = new String[] {
               "Tuvalu Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "Vostok Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "Wallis & Futuna Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "Arabian Standard Time",
               "",
               "Arabian Daylight Time",
               "",
               "Arabian Time",
               "",
            };
        final String[] Armenia = new String[] {
               "Armenia Standard Time",
               "",
               "Armenia Summer Time",
               "",
               "Armenia Time",
               "",
            };
        final String[] Bolivia = new String[] {
               "Aago Bolivia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "Chatham Standard Time",
               "",
               "Chatham Daylight Time",
               "",
               "Chatham Time",
               "",
            };
        final String[] ETC_UTC = new String[] {
               "\u00c0pap\u1ecd\u0300 \u00c0k\u00f3k\u00f2 \u00c0gb\u00e1y\u00e9",
               "UTC",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "Aago Ecuador",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "Gambier Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "Georgia Standard Time",
               "",
               "Georgia Summer Time",
               "",
               "Georgia Time",
               "",
            };
        final String[] Irkutsk = new String[] {
               "Irkutsk Standard Time",
               "",
               "Irkutsk Summer Time",
               "",
               "Irkutsk Time",
               "",
            };
        final String[] Magadan = new String[] {
               "Magadan Standard Time",
               "",
               "Magadan Summer Time",
               "",
               "Magadan Time",
               "",
            };
        final String[] Myanmar = new String[] {
               "Myanmar Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "Norfolk Island Standard Time",
               "",
               "Norfolk Island Daylight Time",
               "",
               "Norfolk Island Time",
               "",
            };
        final String[] Noronha = new String[] {
               "Aago \u00e0s\u00eck\u00f2 Fenando de Norona",
               "",
               "Aago Soma Fernando de Noronha",
               "",
               "Aago Fenando de Norona",
               "",
            };
        final String[] Reunion = new String[] {
               "R\u00e9union Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "Rothera Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "Solomon Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "Tokelau Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "Uruguay Standard Time",
               "",
               "Aago Soma Uruguay",
               "",
               "Aago Uruguay",
               "",
            };
        final String[] Vanuatu = new String[] {
               "Vanuatu Standard Time",
               "",
               "Vanuatu Summer Time",
               "",
               "Vanuatu Time",
               "",
            };
        final String[] Yakutsk = new String[] {
               "Yakutsk Standard Time",
               "",
               "Yakutsk Summer Time",
               "",
               "Yakutsk Time",
               "",
            };
        final String[] Atlantic = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccy\u00e1l\u1eb9ta \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0t\u00ecl\u00e1\u0144t\u00ed\u00eck\u00ec",
               "",
            };
        final String[] Brasilia = new String[] {
               "Aago \u00e0s\u00eck\u00f2 B\u00f9r\u00e0s\u00edl\u00ed\u00e0",
               "",
               "Aago Soma Brasilia",
               "",
               "Aago B\u00f9r\u00e0s\u00edl\u00ed\u00e0",
               "",
            };
        final String[] Chamorro = new String[] {
               "Chamorro Standard Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Colombia = new String[] {
               "Aago \u00e0s\u00eck\u00f2 Kolombia",
               "",
               "Aago Soma Colombia",
               "",
               "Aago Kolombia",
               "",
            };
        final String[] Falkland = new String[] {
               "Falkland Islands Standard Time",
               "",
               "Falkland Islands Summer Time",
               "",
               "Falkland Islands Time",
               "",
            };
        final String[] Malaysia = new String[] {
               "Malaysia Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "Maldives Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "Ulaanbaatar Standard Time",
               "",
               "Ulaanbaatar Summer Time",
               "",
               "Ulaanbaatar Time",
               "",
            };
        final String[] Pakistan = new String[] {
               "Pakistan Standard Time",
               "",
               "Pakistan Summer Time",
               "",
               "Pakistan Time",
               "",
            };
        final String[] Paraguay = new String[] {
               "Paraguay Standard Time",
               "",
               "Paraguay Summer Time",
               "",
               "Paraguay Time",
               "",
            };
        final String[] Pitcairn = new String[] {
               "Pitcairn Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Sakhalin = new String[] {
               "Sakhalin Standard Time",
               "",
               "Sakhalin Summer Time",
               "",
               "Sakhalin Time",
               "",
            };
        final String[] Suriname = new String[] {
               "Suriname Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "Aago \u00e0s\u00eck\u00f2 Argentina",
               "",
               "Aago Soma Argentina",
               "",
               "Aago Aj\u1eb9nt\u00ecn\u00e0",
               "",
            };
        final String[] Christmas = new String[] {
               "Christmas Island Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "Aago Galapago",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "Hong Kong Standard Time",
               "",
               "Hong Kong Summer Time",
               "",
               "Hong Kong Time",
               "",
            };
        final String[] Indochina = new String[] {
               "\u00c0k\u00f3k\u00f2 Indochina",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "Kyrgyzstan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "Lord Howe Standard Time",
               "",
               "Lord Howe Daylight Time",
               "",
               "Lord Howe Time",
               "",
            };
        final String[] Marquesas = new String[] {
               "Marquesas Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "Mauritius Standard Time",
               "",
               "Mauritius Summer Time",
               "",
               "Mauritius Time",
               "",
            };
        final String[] Singapore = new String[] {
               "Singapore Standard Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "Aago Venezuela",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Volgograd = new String[] {
               "Volgograd Standard Time",
               "",
               "Volgograd Summer Time",
               "",
               "Volgograd Time",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "Azerbaijan Standard Time",
               "",
               "Azerbaijan Summer Time",
               "",
               "Azerbaijan Time",
               "",
            };
        final String[] Bangladesh = new String[] {
               "Bangladesh Standard Time",
               "",
               "Bangladesh Summer Time",
               "",
               "Bangladesh Time",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "Cape Verde Standard Time",
               "",
               "Cape Verde Summer Time",
               "",
               "Cape Verde Time",
               "",
            };
        final String[] East_Timor = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccl\u00e0 oor\u00f9n Timor",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "Seychelles Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "Tajikistan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "Uzbekistan Standard Time",
               "",
               "Uzbekistan Summer Time",
               "",
               "Uzbekistan Time",
               "",
            };
        final String[] Afghanistan = new String[] {
               "Afghanistan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "Krasnoyarsk Standard Time",
               "",
               "Krasnoyarsk Summer Time",
               "",
               "Krasnoyarsk Time",
               "",
            };
        final String[] New_Zealand = new String[] {
               "New Zealand Standard Time",
               "",
               "New Zealand Daylight Time",
               "",
               "New Zealand Time",
               "",
            };
        final String[] Novosibirsk = new String[] {
               "Novosibirsk Standard Time",
               "",
               "Novosibirsk Summer Time",
               "",
               "Novosibirsk Time",
               "",
            };
        final String[] Philippines = new String[] {
               "Philippine Standard Time",
               "",
               "Philippine Summer Time",
               "",
               "Philippine Time",
               "",
            };
        final String[] Vladivostok = new String[] {
               "Vladivostok Standard Time",
               "",
               "Vladivostok Summer Time",
               "",
               "Vladivostok Time",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "Indian Ocean Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "Line Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Newfoundland",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd Newfoundland",
               "",
               "\u00c0k\u00f3k\u00f2 Newfoundland",
               "",
            };
        final String[] Turkmenistan = new String[] {
               "Turkmenistan Standard Time",
               "",
               "Turkmenistan Summer Time",
               "",
               "Turkmenistan Time",
               "",
            };
        final String[] French_Guiana = new String[] {
               "French Guiana Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "New Caledonia Standard Time",
               "",
               "New Caledonia Summer Time",
               "",
               "New Caledonia Time",
               "",
            };
        final String[] South_Georgia = new String[] {
               "South Georgia Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "Yekaterinburg Standard Time",
               "",
               "Yekaterinburg Summer Time",
               "",
               "Yekaterinburg Time",
               "",
            };
        final String[] Africa_Central = new String[] {
               "Central Africa Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Eastern = new String[] {
               "East Africa Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Western = new String[] {
               "West Africa Standard Time",
               "",
               "West Africa Summer Time",
               "",
               "West Africa Time",
               "",
            };
        final String[] DumontDUrville = new String[] {
               "Dumont-d\u2019Urville Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin \u00e0sik\u00f2 Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin S\u1ecdm\u00e0 Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e1rin Europe",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00cch\u00e0 \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 S\u1ecdm\u00e0 \u00ccha \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00cch\u00e0 \u00ccl\u00e0 O\u00f2r\u00f9n Europe",
               "",
            };
        final String[] Europe_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 \u00ccw\u1ecd O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 S\u1ecdm\u00e0 \u00cch\u00e0 \u00ccw\u1ecd O\u00f2r\u00f9n Europe",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd O\u00f2r\u00f9n Europe",
               "",
            };
        final String[] Mexico_Pacific = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u1eb9\u0301s\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u1eb9\u0301s\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 P\u00e1s\u00edf\u00ed\u00eck\u00ec M\u1eb9\u0301\u1e63\u00edk\u00f2",
               "",
            };
        final String[] Africa_Southern = new String[] {
               "South Africa Standard Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Central = new String[] {
               "\u00e0k\u00f3k\u00f2 asiko \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
               "",
               "Ak\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n oj\u00fam\u1ecdm\u1ecd",
               "",
               "\u00e0k\u00f3k\u00f2 \u00e0\u00e1r\u00edn gb\u00f9ngb\u00f9n",
               "",
            };
        final String[] America_Eastern = new String[] {
               "Ak\u00f3k\u00f2 \u00c0sik\u00f2 \u00ccha \u00ccla O\u00f2r\u00f9n",
               "",
               "\u00c0k\u00f3k\u00f2 oj\u00fam\u1ecdm\u1ecd \u00cch\u00e0 \u00ccl\u00e0 O\u00f2run",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ech\u00e0 \u00ecl\u00e0 o\u00f2r\u00f9n",
               "",
            };
        final String[] America_Pacific = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00e0sik\u00f2 P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccy\u00e1l\u1eb9ta P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
               "\u00c0k\u00f3k\u00f2 P\u00e0s\u00edf\u00ed\u00eck\u00ec",
               "",
            };
        final String[] French_Southern = new String[] {
               "French Southern & Antarctic Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "Gilbert Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Hawaii-Aleutian",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd Hawaii-Aleutian",
               "",
               "\u00c0k\u00f3k\u00f2 Hawaii-Aleutian",
               "",
            };
        final String[] Phoenix_Islands = new String[] {
               "Phoenix Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Pierre & Miquelon",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd Pierre & Miquelon",
               "",
               "\u00c0k\u00f3k\u00f2 Pierre & Miquelon",
               "",
            };
        final String[] America_Mountain = new String[] {
               "\u00c0k\u00f3k\u00f2 asiko \u00f2k\u00e8",
               "",
               "\u00c0k\u00f3k\u00f2 oj\u00fam\u1ecdm\u1ecd Ori-\u00f2k\u00e8",
               "",
               "\u00c0k\u00f3k\u00f2 \u00f2k\u00e8",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "Marshall Islands Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mexico_Northwest = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 Ap\u00e1 \u00ccw\u1ecd\u0300 Oor\u00f9n M\u1eb9\u0301\u1e63\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Oj\u00fam\u1ecdm\u1ecd Ap\u00e1 \u00ccw\u1ecd\u0300 Oor\u00f9n M\u1eb9\u0301\u1e63\u00edk\u00f2",
               "",
               "\u00c0k\u00f3k\u00f2 Ap\u00e1 \u00ccw\u1ecd\u0300 Oor\u00f9n M\u1eb9\u0301\u1e63\u00edk\u00f2",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "Papua New Guinea Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "Australian Central Standard Time",
               "",
               "Australian Central Daylight Time",
               "",
               "Central Australia Time",
               "",
            };
        final String[] Australia_Eastern = new String[] {
               "Australian Eastern Standard Time",
               "",
               "Australian Eastern Daylight Time",
               "",
               "Eastern Australia Time",
               "",
            };
        final String[] Australia_Western = new String[] {
               "Australian Western Standard Time",
               "",
               "Australian Western Daylight Time",
               "",
               "Western Australia Time",
               "",
            };
        final String[] Greenland_Eastern = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300 \u00ccf\u1eb9nuk\u00f2 oor\u00f9n Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ecgb\u00e0 Ooru Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccl\u00e0 oor\u00f9n Greenland",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u00ccw\u1ecd\u0300 O\u00f2r\u00f9n Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00c0f\u1eb9nuk\u00f2 \u00ccgba O\u00f2ru Greenland",
               "",
               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300 oor\u00f9n Greenland",
               "",
            };
        final String[] Indonesia_Central = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00c0\u00e0rin Gb\u00f9ngb\u00f9n Indonesia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Eastern = new String[] {
               "Eastern Indonesia Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Western = new String[] {
               "\u00c0k\u00f3k\u00f2 \u00ccw\u1ecd\u0300 oor\u00f9n Indonesia",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "East Kazakhstan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "West Kazakhstan Time",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "Australian Central Western Standard Time",
               "",
               "Australian Central Western Daylight Time",
               "",
               "Australian Central Western Time",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", ETC_UTC },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "JST", Japan },
            { "MIT", Apia },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "Etc/UTC", ETC_UTC },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Amman", Europe_Eastern },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Truk },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Apia", Apia },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Damascus", Europe_Eastern },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Sakhalin", Sakhalin },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Ust-Nera", Vladivostok },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "Greenwich Mean Time",
                    "",
                    "Irish Standard Time",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Jersey", GMT },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "Greenwich Mean Time",
                    "",
                    "British Summer Time",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Dawson", America_Mountain },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "Greenwich Mean Time",
                    "",
                    "British Summer Time",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Pacific/Easter", Easter },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Ponape },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "Pacific/Wallis", Wallis },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Mountain },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/Perth", Australia_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey", GMT },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", Maldives },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Mazatlan", Mexico_Pacific },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Novosibirsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Volgograd },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Chihuahua", Mexico_Pacific },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Hermosillo", Mexico_Pacific },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", America_Mountain },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Europe/Isle_of_Man", GMT },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Santa_Isabel", Mexico_Northwest },
            { "America/Scoresbysund", Greenland_Eastern },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Etc/Unknown", "\u00ccl\u00fa \u00c0\u00ecm\u1ecd\u0300" },
            { "timezone.excity.America/Adak", "\u00ecl\u00fa Ad\u00e1k\u00ec" },
            { "timezone.excity.America/Nome", "\u00ecl\u00fa Nomi" },
            { "timezone.excity.America/Aruba", "\u00ecl\u00fa Ar\u00fab\u00e1" },
            { "timezone.excity.America/Boise", "\u00ecl\u00fa B\u1ecd\u0301is\u00e8" },
            { "timezone.excity.America/Sitka", "\u00ecl\u00fa Sika" },
            { "timezone.excity.America/Thule", "\u00ecl\u00fa Tul\u00e8" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.America/Belize", "\u00ecl\u00fa B\u1eb9\u0300l\u00ed\u00ecs\u00ec" },
            { "timezone.excity.America/Cancun", "\u00ecl\u00fa Kancun" },
            { "timezone.excity.America/Cayman", "il\u00fa Kayman" },
            { "timezone.excity.America/Dawson", "\u00ecl\u00fa Dawson" },
            { "timezone.excity.America/Denver", "\u00ecl\u00fa Denver" },
            { "timezone.excity.America/Havana", "\u00ecl\u00fa Havana" },
            { "timezone.excity.America/Inuvik", "\u00ecl\u00fa Inuvik" },
            { "timezone.excity.America/Juneau", "\u00ecl\u00fa Junu" },
            { "timezone.excity.America/Merida", "\u00ecl\u00fa Merida" },
            { "timezone.excity.America/Nassau", "\u00ecl\u00fa Nasa\u00f2" },
            { "timezone.excity.America/Panama", "\u00ecl\u00fa Panama" },
            { "timezone.excity.America/Regina", "\u00ecl\u00fa Regina" },
            { "timezone.excity.America/Antigua", "\u00ecl\u00fa Ant\u00edg\u00f9\u00e0" },
            { "timezone.excity.America/Chicago", "\u00ecl\u00fa Chicago" },
            { "timezone.excity.America/Creston", "\u00ecl\u00fa K\u00edr\u1eb9st\u1ecd\u0301\u1ecd\u0300n\u00f9" },
            { "timezone.excity.America/Curacao", "\u00ecl\u00fa Kura\u1e63ao" },
            { "timezone.excity.America/Detroit", "\u00ecl\u00fa Detroit" },
            { "timezone.excity.America/Godthab", "\u00ecl\u00fa Nuuk" },
            { "timezone.excity.America/Grenada", "\u00ecl\u00fa Grenada" },
            { "timezone.excity.America/Halifax", "\u00ecl\u00fa Halif\u00e1s\u00ec" },
            { "timezone.excity.America/Iqaluit", "\u00ecl\u00fa Iqaluit" },
            { "timezone.excity.America/Jamaica", "\u00ecl\u00fa Jamaik\u00e0" },
            { "timezone.excity.America/Managua", "\u00ecl\u00fa Managua" },
            { "timezone.excity.America/Marigot", "\u00ecl\u00fa Marig\u1ecd\u0301\u1ecd\u0300t\u00ec" },
            { "timezone.excity.America/Moncton", "\u00ecl\u00fa Montoni" },
            { "timezone.excity.America/Nipigon", "\u00ecl\u00fa Nipigoni" },
            { "timezone.excity.America/Ojinaga", "\u00ecl\u00fa Ojinaga" },
            { "timezone.excity.America/Phoenix", "\u00ecl\u00fa F\u00edn\u00eds\u00ec" },
            { "timezone.excity.America/Tijuana", "\u00ecl\u00fa T\u00edj\u00faana" },
            { "timezone.excity.America/Toronto", "\u00ecl\u00fa Toronto" },
            { "timezone.excity.America/Tortola", "\u00ecl\u00fa Totola" },
            { "timezone.excity.America/Yakutat", "\u00ecl\u00fa Yakuta" },
            { "timezone.excity.America/Anguilla", "\u00ecl\u00fa Ang\u00fa\u00edl\u00e0" },
            { "timezone.excity.America/Barbados", "\u00ecl\u00fa B\u00e1b\u00e1d\u1ecd\u0301\u1ecd\u0300s\u00ec" },
            { "timezone.excity.America/Dominica", "\u00ecl\u00fa Dominika" },
            { "timezone.excity.America/Edmonton", "\u00ecl\u00fa Edmonton" },
            { "timezone.excity.America/Mazatlan", "\u00ecl\u00fa Masatiani" },
            { "timezone.excity.America/Miquelon", "\u00ecl\u00fa Mikul\u1ecd\u0301n\u00ec" },
            { "timezone.excity.America/New_York", "\u00ecl\u00fa New York" },
            { "timezone.excity.America/Resolute", "\u00ecl\u00fa Resol\u00fat\u00ec" },
            { "timezone.excity.America/St_Johns", "\u00ecl\u00fa St J\u1ecd\u0301\u1ecd\u0300n\u00f9" },
            { "timezone.excity.America/St_Kitts", "\u00ecl\u00fa St kitis\u00ec" },
            { "timezone.excity.America/St_Lucia", "\u00ecl\u00fa St Lusia" },
            { "timezone.excity.America/Winnipeg", "\u00ecl\u00fa Winipeg\u00ec" },
            { "timezone.excity.Atlantic/Bermuda", "\u00ecl\u00fa B\u1eb9\u0300m\u00fad\u00e0" },
            { "timezone.excity.America/Anchorage", "\u00ecl\u00fa Ank\u1ecd\u0301r\u00e9\u00e8j\u00ec" },
            { "timezone.excity.America/Chihuahua", "\u00ecl\u00fa \u1e62ihuahua" },
            { "timezone.excity.America/Glace_Bay", "\u00ecl\u00fa omi Glace" },
            { "timezone.excity.America/Goose_Bay", "\u00ecl\u00fa omi Goos\u00f9" },
            { "timezone.excity.America/Guatemala", "\u00ecl\u00fa Guatemala" },
            { "timezone.excity.America/Matamoros", "\u00ecl\u00fa Matamoros\u00ec" },
            { "timezone.excity.America/Menominee", "\u00ecl\u00fa Menomin\u00ec" },
            { "timezone.excity.America/Monterrey", "\u00ecl\u00fa Monteri" },
            { "timezone.excity.America/St_Thomas", "\u00ecl\u00fa St T\u1ecd\u0301m\u00e0s\u00ec" },
            { "timezone.excity.America/Vancouver", "\u00ecl\u00fa Vankuva" },
            { "timezone.excity.America/Costa_Rica", "\u00ecl\u00fa Kosta R\u00edk\u00e0" },
            { "timezone.excity.America/Grand_Turk", "\u00ecl\u00fa Grand Turk" },
            { "timezone.excity.America/Guadeloupe", "\u00ecl\u00fa Guadeloupe" },
            { "timezone.excity.America/Hermosillo", "\u00ecl\u00fa Hermosilo" },
            { "timezone.excity.America/Kralendijk", "\u00ecl\u00fa K\u00edral\u1eb9\u0301nd\u00e1ik\u00ec" },
            { "timezone.excity.America/Louisville", "\u00ecl\u00fa L\u00fa\u00edf\u00ed\u00ecl\u00ec" },
            { "timezone.excity.America/Martinique", "\u00ecl\u00fa M\u00e1t\u00edn\u00edk\u00ec" },
            { "timezone.excity.America/Metlakatla", "\u00ecl\u00fa Metilakatila" },
            { "timezone.excity.America/Montserrat", "\u00ecl\u00fa Monserat\u00ec" },
            { "timezone.excity.America/St_Vincent", "\u00ecl\u00fa Finsent\u00ec" },
            { "timezone.excity.America/Whitehorse", "\u00ecl\u00fa Whitehos\u00ec" },
            { "timezone.excity.America/El_Salvador", "\u00ecl\u00fa El Savador" },
            { "timezone.excity.America/Fort_Nelson", "\u00ecl\u00fa Fort Nelson" },
            { "timezone.excity.America/Los_Angeles", "\u00ecl\u00fa Los Angeles" },
            { "timezone.excity.America/Mexico_City", "\u00ecl\u00fa M\u1eb9\u0301s\u00edk\u00f2" },
            { "timezone.excity.America/Pangnirtung", "\u00ecl\u00fa Panituni" },
            { "timezone.excity.America/Puerto_Rico", "\u00ecl\u00fa Puerto Riko" },
            { "timezone.excity.America/Rainy_River", "\u00ecl\u00fa Raini Rif\u00e0" },
            { "timezone.excity.America/Tegucigalpa", "\u00ecl\u00fa Tegusigap\u00e0" },
            { "timezone.excity.America/Thunder_Bay", "\u00ecl\u00fa Omi Thunder" },
            { "timezone.excity.America/Yellowknife", "\u00ecl\u00fa Yelon\u00e1f\u00f9" },
            { "timezone.excity.America/Blanc-Sablon", "\u00ecl\u00fa Blank Sabul\u1ecd\u0301\u1ecd\u0300n\u00ec" },
            { "timezone.excity.America/Danmarkshavn", "\u00ecl\u00fa Banmarkshan" },
            { "timezone.excity.America/Dawson_Creek", "\u00ecl\u00fa Dawson Creek" },
            { "timezone.excity.America/Indiana/Knox", "\u00ecl\u00fa n\u1ecd\u0301s\u00ec" },
            { "timezone.excity.America/Indianapolis", "\u00ecl\u00fa Indianapolis" },
            { "timezone.excity.America/Rankin_Inlet", "\u00ecl\u00fa Rankin Inlet" },
            { "timezone.excity.America/Scoresbysund", "\u00ecl\u00fa Itokotomiti" },
            { "timezone.excity.America/Cambridge_Bay", "\u00ecl\u00fa \u00f2kun kamb\u00edr\u00ed\u00ecj\u00ec" },
            { "timezone.excity.America/Coral_Harbour", "\u00ecl\u00fa \u00e0tik\u1ecdk\u00e0n" },
            { "timezone.excity.America/Indiana/Vevay", "\u00ecl\u00fa Vevay" },
            { "timezone.excity.America/Lower_Princes", "\u00ecl\u00fa Lower Prince\u2019s Quarter" },
            { "timezone.excity.America/Port_of_Spain", "\u00ecl\u00fa et\u00ed omi S\u00edp\u00e9\u00e8n\u00ec" },
            { "timezone.excity.America/Santo_Domingo", "\u00ecl\u00fa Santo Domigo" },
            { "timezone.excity.America/St_Barthelemy", "\u00ecl\u00fa Batilem\u00ec" },
            { "timezone.excity.America/Swift_Current", "\u00ecl\u00fa S\u00faf\u00edt\u00f9 K\u1ecd\u0300rent\u00ec" },
            { "timezone.excity.America/Bahia_Banderas", "\u00ecl\u00fa B\u00e1h\u00ec B\u00e1nd\u1eb9\u0301r\u00e1s\u00ec" },
            { "timezone.excity.America/Port-au-Prince", "\u00ecl\u00fa Port-au-Prince" },
            { "timezone.excity.America/Indiana/Marengo", "\u00ecl\u00fa Mar\u1eb9\u0301ngo" },
            { "timezone.excity.America/Indiana/Winamac", "\u00ecl\u00fa Winamak n\u00ed Indiana" },
            { "timezone.excity.America/Indiana/Tell_City", "\u00ecl\u00fa Tell City" },
            { "timezone.excity.America/Indiana/Vincennes", "\u00ecl\u00fa Vincennes n\u00ed Indiana" },
            { "timezone.excity.America/Indiana/Petersburg", "\u00ecl\u00fa Petersburg" },
            { "timezone.excity.America/Kentucky/Monticello", "\u00ecl\u00fa Montis\u1eb9\u0301l\u00f2" },
            { "timezone.excity.America/North_Dakota/Beulah", "\u00ecl\u00fa Beul\u00e0 n\u00ed North Dakota" },
            { "timezone.excity.America/North_Dakota/Center", "\u00ecl\u00fa Senta North Dakota" },
            { "timezone.excity.America/North_Dakota/New_Salem", "\u00ecl\u00fa New Salem ni North Dakota" },
        };
        return data;
    }
}
